#!/usr/bin/env python
"""
 @file: AllSys.py
  File is a part of Scribo Project
  Module implements starting of all tests
  @author: Kirill Germanov <kgermano@cs.karelia.ru>
  @date: 23.03.2010
"""

import sys
sys.path.append("..")
sys.path.append("../ldm")
sys.path.append("../ui")
sys.path.append("../services")

import test.SysTest
import test.SysFT
import test.BDTest




__author__ = "Kirill Germanov <kgermano@cs.karelia.ru>"
__version__ = "$Revision: 0.1 $"
__date__ = "$Date: 2010/02/14 $"
__copyright__ = ""
__license__ = "GPLv2"

class ALLTESTS:
    """
    Class with test method for SendPost module
    @version  1.0
    @author  Germanov Kirill <kgermano@cs.karelia.ru>
    @todo  global testing of all scenarios
    """
    def __init__(self):
        """
        initialization of test account
        @return
        """
        print "Run~!"


